@@ -66,7 +66,7 @@ class MIB_SQLite(MIB):
         try:
             if type_ in [4]:
                 aux = ""
-                for c in str(value):
+                for c in value:
                     aux += str(struct.unpack('!B', c.encode('charmap'))[0]) + ","
                 value = "char(" + aux[0:-1] + ")"
                 self.cursor.execute('INSERT INTO ' + self.table_name + ' (oid, type, value) VALUES ("%(oid)s", %(type)s, %(value)s) ON CONFLICT(oid) DO UPDATE SET type=%(type)s, value=%(value)s;' % {"oid": oid, "type": type_, "value": value})
